####################################################################
# Monte Carlo Test
# Vanilla SE vs. Cluster SE vs. Cluster-Adjusted SE
# 
# Linear Model
####################################################################

clusterIMtestProbit<-function(obs.per.cluster, g.sd, reps=1000){
  
  total.obs <- sum(obs.per.cluster)
  n.clusters <- length(obs.per.cluster)
  
  vn.res <- matrix(data=NA, nrow=reps, ncol=3)
  cl.res <- matrix(data=NA, nrow=reps, ncol=3)
  mx.res <- matrix(data=NA, nrow=reps, ncol=3)
  im.res <- matrix(data=NA, nrow=reps, ncol=3)
  bs.res.v <- matrix(data=NA, nrow=reps, ncol=3)
  bs.res.c <- matrix(data=NA, nrow=reps, ncol=3)
  
  # load in a function to create clustered standard errors
  # by Mahmood Ara: http://thetarzan.wordpress.com/2011/06/11/clustered-standard-errors-in-r/
  cl   <- function(dat, fm, cluster){
    require(sandwich, quietly = TRUE)
    require(lmtest, quietly = TRUE)
    M <- length(unique(cluster))
    N <- length(cluster)
    K <- fm$rank
    dfc <- (M/(M-1))
    uj  <- apply(estfun(fm),2, function(x) tapply(x, cluster, sum));
    vcovCL <- dfc*sandwich(fm, meat=crossprod(uj)/N)
    coeftest(fm, vcovCL, df=(M-1)) }
  
  pb <- txtProgressBar(min=0, max=reps, initial=0, style=3)
  for(i in 1:reps){
    
    setTxtProgressBar(pb, value=i)

    mod <- NA
    
    # while loop protects against problem data sets
    while(max(is.na(mod))){        
      
      g <- rep(1:n.clusters, times=obs.per.cluster)
      g.ef <- rnorm(n.clusters, mean = 0, sd = g.sd)
      g.ob <- g.ef[g]
      
      x.mean <- runif(n.clusters, min = 1, max = 5)
      x <- rnorm( total.obs, mean = x.mean[g], sd = 1 )
      z <- rnorm( total.obs, mean = 0, sd = 1)
      w <- rnorm( total.obs, mean = 0, sd = 1)
      
      y.prob <- pnorm(0.25*x + 0.25*z + w + g.ob, mean=0, sd=1)
      y <- as.numeric(runif(length(y.prob)) < y.prob)
      
      dat<-data.frame(y,x,z,w,g)
      
      mod<-suppressWarnings(tryCatch(glm(y~x+z+w, family=binomial(link="probit"), data=dat), error = function(e){return(NA)}))
      if(mod$converged == 0){mod <- NA}
      
      if(length(unique(y)) < 2){mod <- NA}  # reject any data sets that have no variation in the DV
      
    }
    
    vn.res[i,] <- summary(mod)$coefficients[2:4, 4]
    cl.res[i,] <- cl(dat, mod, g)[2:4, 4]
    mx.res[i,] <- apply(rbind(vn.res[i,], cl.res[i,]), MARGIN=2, FUN=max)
    im.res[i,] <- tryCatch(cluster.im.glm(mod, dat, ~g, report = F, drop = F)$p.values[2:4], error = function(e){return(NA)})
    bs.res.v[i,] <- cluster.bs.glm(mod, dat, ~g, report = F, boot.reps=100, prog.bar=F, cluster.se = FALSE)$p.values[2:4]
    bs.res.c[i,] <- cluster.bs.glm(mod, dat, ~g, report = F, boot.reps=100, prog.bar=F, cluster.se = TRUE)$p.values[2:4]
    
  }
  close(pb)
  
  save.name <- paste("power-binary-clusters-", as.character(n.clusters), "_unique-", as.character(length(unique(obs.per.cluster))), "_sd-", g.sd, ".RData", sep="")
  list.out <- list(vn.res=vn.res, cl.res=cl.res, mx.res=mx.res, im.res=im.res, bs.res.v=bs.res.v, bs.res.c=bs.res.c)
  save(list.out, file=save.name)
  
  
}
