rm(list=ls())
library(foreign)
library(mlogit)

set.seed(123456)

dat <- read.dta("LacinaAJPSreplication.dta")

dat.m <- mlogit.data(dat, choice="outcome_tri", shape="wide")

lacina.mlogit <- mlogit(outcome_tri ~ 0 | lnrelgrepnm + lnrelgrepnm2 + polsim + lnelgmps + lnelpop + eagpc + elndlss + ehindupc + lcapdist, data=dat.m) 

# vanilla SEs
summary(lacina.mlogit)

# cluster bootstrapped SEs
library(clusterSEs)
cluster.bs.mlogit(lacina.mlogit, dat.m, ~ snum, boot.reps=1000)

# load in a function to create clustered standard errors for mlogit models
# initial code by Mahmood Ara: http://thetarzan.wordpress.com/2011/06/11/clustered-standard-errors-in-r/
# slightly modified for mlogit models by Justin Esarey on 3/3/2015

cl.mlogit   <- function(fm, cluster){
  
  # fm: a fitted mlogit model
  # cluster: a data vector with the cluster
  #          identity of each observation in fm
  
  require(sandwich, quietly = TRUE)
  require(lmtest, quietly = TRUE)
  M <- length(unique(cluster))
  N <- length(cluster)
  K <- length(coefficients(fm))
  #dfc <- (M/(M-1))*((N-1)/(N-K))
  dfc <- M/(M-1)
  uj  <- apply(estfun(fm),2, function(x) tapply(x, cluster, sum));
  vcovCL <- dfc*sandwich(fm, meat.=crossprod(uj)/N)
  coeftest(fm, vcovCL) }

# clustered SEs
# note: SEs match, but p-values don't b/c R doesn't adjust for DF in t-distribution
cl.mlogit(lacina.mlogit, dat$snum)